pub enum Instruction {
Show 17 variants
Add(Add),
Arg(Arg),
Cmd(Cmd),
Copy(Copy),
Entrypoint(Entrypoint),
Env(Env),
Expose(Expose),
HealthCheck(HealthCheck),
Label(Label),
Maintainer(Maintainer),
OnBuild(OnBuild),
Run(Run),
Shell(Shell),
StopSignal(StopSignal),
User(User),
Volume(Volume),
Workdir(WorkDir),
}Expand description
The Instruction is one of the 3 core units of the Dockerfile Rust Intermediate Representation
It directly represents a typed version of Dockerfile Instruction.
Note that the From Instruction is not available, this is becuase each stage can only have one From instruction so it is defined in the stage
Variants
Add(Add)
Arg(Arg)
Cmd(Cmd)
Copy(Copy)
Entrypoint(Entrypoint)
Env(Env)
Expose(Expose)
HealthCheck(HealthCheck)
Label(Label)
Maintainer(Maintainer)
OnBuild(OnBuild)
Run(Run)
Shell(Shell)
StopSignal(StopSignal)
User(User)
Volume(Volume)
Workdir(WorkDir)