pub struct Stage {
pub pre_from_instructions: Vec<PreFromInstruction>,
pub from: From,
pub instructions: Vec<Instruction>,
}Expand description
The Stage is the unit which sits above the Instruction. It contains a vector of instructions to be placed before and after the FROM command
Fields
pre_from_instructions: Vec<PreFromInstruction>from: Frominstructions: Vec<Instruction>Trait Implementations